import os
import sys
import subprocess
from textwrap import dedent


def print_green(skk):
    print("\033[92m {}\033[00m".format(skk))


def get_venv_path():
    home_dir = os.path.expanduser("~")
    venv_dir = os.path.join(home_dir, ".venvs")
    if not os.path.exists(venv_dir):
        os.makedirs(venv_dir)
    return os.path.join(venv_dir, "wttrman_venv")


def create_venv(venv_path):
    print("Creating the virtual environment...", end="")
    sys.stdout.flush()
    subprocess.run(
        ["python3", "-m", "venv", venv_path],
        check=True,
        stdout=subprocess.DEVNULL,
        stderr=subprocess.DEVNULL,
    )
    print_green("󰄬")

    print("Ensuring pip is up to date...", end="")
    sys.stdout.flush()
    pip_path = os.path.join(venv_path, "bin", "pip")
    subprocess.run(
        [pip_path, "install", "--upgrade", "pip"],
        check=True,
        stdout=subprocess.DEVNULL,
        stderr=subprocess.DEVNULL,
    )
    print_green("󰄬")


def install_app(venv_path):
    print("Installing Wttrman into the virtual environment...", end="")
    sys.stdout.flush()
    pip_path = os.path.join(venv_path, "bin", "pip")
    subprocess.run(
        [pip_path, "install", "wttrman"],
        check=True,
        stdout=subprocess.DEVNULL,
        stderr=subprocess.DEVNULL,
    )
    print_green("󰄬")


def get_icon(venv_path):
    site_packages = os.path.join(venv_path, "lib")
    for folder in os.listdir(site_packages):
        if folder.startswith("python"):
            site_packages = os.path.join(site_packages, folder, "site-packages")
            break

    icon_relative_path = "wttrman/resources/images/wttrman-128.png"
    full_icon_path = os.path.join(site_packages, icon_relative_path)
    return full_icon_path


def get_python_path(venv_path):
    return os.path.join(venv_path, "bin", "python3")


def get_app_path(venv_path):
    return os.path.join(venv_path, "bin", "wttrman")


def create_desktop_file(icon, version, python, app):
    print("Creating the .desktop entry...", end="")
    sys.stdout.flush()
    desktop_content = dedent(f"""
    [Desktop Entry]
    Version={version}
    Type=Application
    Name=Wttrman
    Comment=GUI front-end to https://wttr.in/.
    Exec={python} {app}
    Icon={icon}
    Terminal=false
    Categories=Utility;
    """)
    desktop_content = desktop_content.lstrip()
    with open(
        os.path.expanduser("~/.local/share/applications/wttrman.desktop"),
        "w",
    ) as f:
        f.write(desktop_content)
    print_green("󰄬")


def install():
    venv_path = get_venv_path()
    create_venv(venv_path)
    install_app(venv_path)
    version = "1.2.2"
    icon = get_icon(venv_path)
    python = get_python_path(venv_path)
    app = get_app_path(venv_path)
    create_desktop_file(icon, version, python, app)


def main():
    install()


if __name__ == "__main__":
    main()



from requests import get


class Wttr:
    def __init__(self):
        self.base_url = "https://wttr.in/"

    def get_weather(self, city="", state="", country="USA"):
        city = self.text_fixer(city)
        state = self.text_fixer(state)
        output_format = r"?format=Condition:+%C+\nPrecip:+%p/3 hours+\nTemps:+%t(%f)"
        url = f"{self.base_url}{city}+{state}+{country}{output_format}"
        weather = get(url, timeout=5)
        return weather.text

    def text_fixer(self, text=""):
        counter = 0
        text = list(text)
        for character in text:
            if text[counter] == " ":
                text[counter] = "+"
            counter += 1

        return "".join(text)




"""
GUI front-end to https://wttr.in/.
"""

import sys

from PySide6.QtCore import Qt
from PySide6.QtGui import QFont
from PySide6.QtWidgets import (
    QApplication,
    QMainWindow,
    QWidget,
    QPushButton,
    QComboBox,
    QGridLayout,
    QLabel,
)

from wttrman.wttr import Wttr
from wttrman.yaml_file_handler import YamlFileHandler

config_file = YamlFileHandler("resources/configs/config.yaml")
config = config_file.load_yaml_file()

themes_file = YamlFileHandler("resources/configs/themes.yaml")
themes = themes_file.load_yaml_file()

locations_file = YamlFileHandler("resources/configs/locations.yaml")
locations = locations_file.load_yaml_file()


class Wttrman(QMainWindow):
    def __init__(self):
        super().__init__()
        self.init_ui()

    def init_ui(self):
        self.show()

        # * Set window default settings
        self.setWindowTitle(config["window_title"])
        self.setFixedSize(
            config["window_size"]["width"], config["window_size"]["height"]
        )

        # * Create widgets
        self.get_weather = QPushButton("Get Weather")

        self.city = QComboBox()
        self.city.addItem("Select City")

        self.state = QComboBox()
        self.state.addItem("Select State")
        self.state.addItems(state for state in locations["states"])

        self.theme_toggle = QPushButton("Dark")

        self.weather = QLabel(
            " ", alignment=Qt.AlignmentFlag.AlignCenter, wordWrap=True
        )
        self.weather.setFixedWidth(config["weather_widget_width"])

        # * Define button connections
        self.get_weather.pressed.connect(self.wttr)
        self.state.currentIndexChanged.connect(self.update_cities)
        self.theme_toggle.pressed.connect(self.toggle_theme)

        # * Create layouts
        self.page = QGridLayout()
        self.inputs = QGridLayout()
        self.inputs.setVerticalSpacing(5)
        self.outputs = QGridLayout()

        # * Add widgets to layouts
        self.inputs.addWidget(self.get_weather, 0, 0, 1, 2)
        self.inputs.addWidget(self.state, 1, 0, 1, 2)
        self.inputs.addWidget(self.city, 2, 0, 1, 2)
        self.inputs.addWidget(self.theme_toggle, 3, 0, 1, 2)

        self.outputs.addWidget(self.weather, 0, 0, 1, 2)

        # * Setup overall page layout and set default window theme
        self.page.addLayout(self.inputs, 0, 0)
        self.page.addLayout(self.outputs, 0, 1)

        self.gui = QWidget()
        self.gui.setLayout(self.page)

        self.setCentralWidget(self.gui)

        self.apply_theme(self.theme_toggle.text().lower())
        self.set_font()

    def wttr(self):
        forecast = Wttr()
        if self.state.currentText() == "Select State":
            self.weather.setText("You must select a state!")
        elif self.city.currentText() == "Select City":
            self.weather.setText("You must select a city!")
        else:
            self.weather.setText(
                forecast.get_weather(
                    self.city.currentText(),
                    self.state.currentText(),
                )
            )

    def update_cities(self):
        self.city.clear()
        self.city.addItem("Select City")
        self.city.addItems(
            city for city in locations["cities"][self.state.currentText()]
        )

    def toggle_theme(self):
        if self.theme_toggle.text() == "Dark":
            self.theme_toggle.setText("Light")
            theme = self.theme_toggle.text()
        else:
            self.theme_toggle.setText("Dark")
            theme = self.theme_toggle.text()

        self.apply_theme(theme.lower())

    def apply_theme(self, theme):
        self.main_stylesheet = f"""
            background-color: {themes[theme]["background-color"]};
            color: {themes[theme]["color"]};
            border: {themes[theme]["border"]};
            border-radius: {themes["general"]["border-radius"]};
            padding: {themes["general"]["padding"]};
            """
        self.widget_stylesheet = f"""
            background-color: {themes[theme]["widget-background-color"]};
            """
        self.setStyleSheet(self.main_stylesheet)
        self.get_weather.setStyleSheet(self.widget_stylesheet)
        self.city.setStyleSheet(self.widget_stylesheet)
        self.state.setStyleSheet(self.widget_stylesheet)
        self.weather.setStyleSheet(self.widget_stylesheet)
        self.theme_toggle.setStyleSheet(self.widget_stylesheet)

        (
            self.theme_toggle.setText("Dark")
            if theme == "dark"
            else self.theme_toggle.setText("Light")
        )

    def set_font(self):
        font = QFont("Commit Mono Nerd Font", 10)
        weather_font = QFont("Commit Mono Nerd Font", 12)

        self.setFont(font)
        self.get_weather.setFont(font)
        self.city.setFont(font)
        self.state.setFont(font)
        self.weather.setFont(weather_font)
        self.theme_toggle.setFont(font)


def main():
    app = QApplication(sys.argv)
    main_window = Wttrman()  # noqa: F841
    sys.exit(app.exec())


if __name__ == "__main__":
    main()



import os
import sys
import shutil


def print_green(skk):
    print("\033[92m {}\033[00m".format(skk))


def get_venv_path():
    home_dir = os.path.expanduser("~")
    venv_dir = os.path.join(home_dir, ".venvs")
    return os.path.join(venv_dir, "wttrman_venv")


def get_desktop_file_path():
    return os.path.expanduser("~/.local/share/applications/wttrman.desktop")


def uninstall():
    venv_path = get_venv_path()
    desktop_file_path = get_desktop_file_path()

    if os.path.exists(venv_path):
        print("Removing the virtual environment...", end="")
        sys.stdout.flush()
        shutil.rmtree(venv_path)
        print_green("󰄬")

    if os.path.exists(desktop_file_path):
        print("Removing the .desktop entry...", end="")
        sys.stdout.flush()
        os.remove(desktop_file_path)
        print_green("󰄬")


def main():
    uninstall()


if __name__ == "__main__":
    main()



import os
import yaml


class YamlFileHandler:
    def __init__(self, filename):
        self.filename = filename

    def load_yaml_file(self):
        with open(self.get_file_path(), "r") as f:
            return yaml.safe_load(f)

    def save_yaml_file(self, configs):
        with open(self.get_file_path(), "w") as f:
            return yaml.safe_dump(configs, f, default_flow_style=False)

    def get_file_path(self):
        return os.path.join(os.path.dirname(__file__), self.filename)
